@@ -4,18 +4,18 @@ message("writeMat() ...")
 
 message("writeMat() - basic objects ...")
 
-A <- matrix(1:27, nrow=9, ncol=3)
+A <- matrix(1:27, nrow = 9, ncol = 3)
 B <- as.matrix(1:10)
-C <- matrix(c(TRUE, FALSE, FALSE, TRUE), nrow=2, ncol=2)
-D <- array(1:18, dim=c(2,3,3))
+C <- matrix(c(TRUE, FALSE, FALSE, TRUE), nrow = 2, ncol = 2)
+D <- array(1:18, dim = c(2, 3, 3))
 
 Cint <- local({ mode(C) <- "integer"; C })
-truth <- list(A=A, B=B, C=Cint, D=D)
+truth <- list(A = A, B = B, C = Cint, D = D)
 
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 
-writeMat(filename, A=A, B=B, C=C, D=D, verbose=-120)
+writeMat(filename, A = A, B = B, C = C, D = D, verbose = -120)
 data <- readMat(filename)
 str(data)
 stopifnot(all.equal(truth, data[names(truth)]))
@@ -23,10 +23,10 @@ stopifnot(all.equal(truth, data[names(truth)]))
 unlink(filename)
 
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 
 ## Files are overwritten without notice
-writeMat(filename, A=A, B=B, C=C, D=D)
+writeMat(filename, A = A, B = B, C = C, D = D)
 data <- readMat(filename)
 str(data)
 stopifnot(all.equal(truth, data[names(truth)]))
@@ -36,18 +36,18 @@ unlink(filename)
 
 message("writeMat() - to connection ...")
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 con <- file(filename)
 
 ## Files are overwritten without notice
-writeMat(con, A=A, B=B, C=C, D=D, verbose=TRUE)
+writeMat(con, A = A, B = B, C = C, D = D, verbose = TRUE)
 
 con <- file(filename)
 data <- readMat(con)
 str(data)
 stopifnot(all.equal(truth, data[names(truth)]))
 
-raw <- readBin(filename, what="raw", n=1e6)
+raw <- readBin(filename, what = "raw", n = 1e6)
 data <- readMat(raw)
 str(data)
 stopifnot(all.equal(truth, data[names(truth)]))
@@ -67,8 +67,8 @@ message("writeMat() - complex objects ...")
 
 F <- matrix(1i^ (-6:5), nrow = 4)
 
-filename <- paste(tempfile(), ".mat", sep="")
-writeMat(filename, F=F, verbose=-120)
+filename <- paste(tempfile(), ".mat", sep = "")
+writeMat(filename, F = F, verbose = -120)
 data <- readMat(filename)
 str(data)
 stopifnot(all.equal(data$F, F))
@@ -83,11 +83,11 @@ message("writeMat() - complex objects ... DONE")
 message("writeMat() - character objects ...")
 
 e <- paste("letter:", letters)
-E <- matrix(c(e, letters), nrow=13, ncol=4)
+E <- matrix(c(e, letters), nrow = 13, ncol = 4)
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 
-writeMat(filename, e=e, verbose=-120)
+writeMat(filename, e = e, verbose = -120)
 data <- readMat(filename)
 str(data)
 stopifnot(length(data$e) == length(e))
@@ -95,9 +95,9 @@ stopifnot(length(data$e) == length(e))
 unlink(filename)
 
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 
-writeMat(filename, E=E, verbose=-120)
+writeMat(filename, E = E, verbose = -120)
 data <- readMat(filename)
 str(data)
 stopifnot(length(data$E) == length(E))
@@ -112,23 +112,24 @@ message("writeMat() - character objects ... DONE")
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 message("writeMat() - multidimensional arrays ...")
 
-filename <- paste(tempfile(), ".mat", sep="")
-X <- array(1:24, dim=c(2,3,4))
-writeMat(filename, X=X)
+filename <- paste(tempfile(), ".mat", sep = "")
+X <- array(1:24, dim = c(2, 3, 4))
+writeMat(filename, X = X)
 data <- readMat(filename)
 str(data)
 stopifnot(all.equal(data$X, X))
 unlink(filename)
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 A <- 1:4
-X <- array(1:24, dim=c(2,3,4))
-data <- list(A=A, X=X)
-writeMat(filename, data=data)
+X <- array(1:24, dim = c(2, 3, 4))
+data <- list(A = A, X = X)
+writeMat(filename, data = data)
 data2 <- readMat(filename)$data
 str(data2)
 ## FIXME: https://github.com/HenrikBengtsson/R.matlab/issues/30
-## stopifnot(all.equal(data2$A, data$A), all.equal(data2$X, data$X), all.equal(data2, data))
+## stopifnot(all.equal(data2$A, data$A), all.equal(data2$X, data$X),
+##           all.equal(data2, data))
 unlink(filename)
 
 message("writeMat() - multidimensional arrays ... DONE")
@@ -146,8 +147,8 @@ onWrite <- function(...) {
   g <<- g + 1L
 }
 
-filename <- paste(tempfile(), ".mat", sep="")
-writeMat(filename, x=1, onWrite=onWrite)
+filename <- paste(tempfile(), ".mat", sep = "")
+writeMat(filename, x = 1, onWrite = onWrite)
 unlink(filename)
 print(g)
 stopifnot(g == 1L)
@@ -159,30 +160,30 @@ message("writeMat() - onWrite ... DONE")
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 message("writeMat() - fixNames ...")
 
-truth <- list(a.b=1, c_d=2, e_f.g=3, x=4)
+truth <- list(a.b = 1, c_d = 2, e_f.g = 3, x = 4)
 str(truth)
 names <- names(truth)
-names. <- gsub("_", ".", names(truth), fixed=TRUE)
-names_ <- gsub(".", "_", names(truth), fixed=TRUE)
+names. <- gsub("_", ".", names(truth), fixed = TRUE)
+names_ <- gsub(".", "_", names(truth), fixed = TRUE)
 
 message("writeMat() - fixNames and variable names ...")
 
-filename <- paste(tempfile(), ".mat", sep="")
-do.call(writeMat, args=c(list(filename), truth, fixNames=FALSE))
-data <- readMat(filename, fixNames=FALSE)
+filename <- paste(tempfile(), ".mat", sep = "")
+do.call(writeMat, args = c(list(filename), truth, fixNames = FALSE))
+data <- readMat(filename, fixNames = FALSE)
 str(data)
 stopifnot(length(data) == length(truth), all(names(data) == names))
-data <- readMat(filename, fixNames=TRUE)
+data <- readMat(filename, fixNames = TRUE)
 str(data)
 stopifnot(length(data) == length(truth), all(names(data) == names.))
 unlink(filename)
 
-filename <- paste(tempfile(), ".mat", sep="")
-do.call(writeMat, args=c(list(filename), truth, fixNames=TRUE))
-data <- readMat(filename, fixNames=FALSE)
+filename <- paste(tempfile(), ".mat", sep = "")
+do.call(writeMat, args = c(list(filename), truth, fixNames = TRUE))
+data <- readMat(filename, fixNames = FALSE)
 str(data)
 stopifnot(length(data) == length(truth), all(names(data) == names_))
-data <- readMat(filename, fixNames=TRUE)
+data <- readMat(filename, fixNames = TRUE)
 str(data)
 stopifnot(length(data) == length(truth), all(names(data) == names.))
 unlink(filename)
@@ -191,22 +192,22 @@ message("writeMat() - fixNames and variable names ... DONE")
 
 message("writeMat() - fixNames and field names ...")
 
-filename <- paste(tempfile(), ".mat", sep="")
-writeMat(filename, x=truth, fixNames=FALSE)
-data <- readMat(filename, fixNames=FALSE)
+filename <- paste(tempfile(), ".mat", sep = "")
+writeMat(filename, x = truth, fixNames = FALSE)
+data <- readMat(filename, fixNames = FALSE)
 str(data)
 stopifnot(nrow(data) == length(truth), all(rownames(data$x) == names))
-data <- readMat(filename, fixNames=TRUE)
+data <- readMat(filename, fixNames = TRUE)
 str(data)
 stopifnot(nrow(data) == length(truth), all(rownames(data$x) == names.))
 unlink(filename)
 
-filename <- paste(tempfile(), ".mat", sep="")
-writeMat(filename, x=truth, fixNames=TRUE)
-data <- readMat(filename, fixNames=FALSE)
+filename <- paste(tempfile(), ".mat", sep = "")
+writeMat(filename, x = truth, fixNames = TRUE)
+data <- readMat(filename, fixNames = FALSE)
 str(data)
 stopifnot(nrow(data) == length(truth), all(rownames(data$x) == names_))
-data <- readMat(filename, fixNames=TRUE)
+data <- readMat(filename, fixNames = TRUE)
 str(data)
 stopifnot(nrow(data) == length(truth), all(rownames(data$x) == names.))
 unlink(filename)
@@ -220,48 +221,48 @@ message("writeMat() - fixNames ... DONE")
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 message("writeMat() - exceptions ...")
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 tryCatch({
   # Named
-  writeMat(filename, A=A, verbose=-120)
+  writeMat(filename, A = A, verbose = -120)
   # Not named
-  writeMat(filename, A, verbose=-120)
+  writeMat(filename, A, verbose = -120)
 }, error = function(ex) {
   cat("ERROR:", ex$message, "\n")
 })
 unlink(filename)
 
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 tryCatch({
   # Uniquely named
-  writeMat(filename, A=A, B=B, C=C, verbose=-120)
+  writeMat(filename, A = A, B = B, C = C, verbose = -120)
   # Not uniquely named
-  writeMat(filename, A=A, B=B, A=C, verbose=-120)
+  writeMat(filename, A = A, B = B, A = C, verbose = -120)
 }, error = function(ex) {
   cat("ERROR:", ex$message, "\n")
 })
 unlink(filename)
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 res <- tryCatch({
-  writeMat(filename, expr=substitute(x <- 2))
-}, error = function(ex) ex)
+  writeMat(filename, expr = substitute(x <- 2))
+}, error = identity)
 print(res)
 unlink(filename)
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 res <- tryCatch({
-  writeMat(filename, formula=y ~ x)
-}, error = function(ex) ex)
+  writeMat(filename, formula = y ~ x)
+}, error = identity)
 print(res)
 unlink(filename)
 
 
-filename <- paste(tempfile(), ".mat", sep="")
+filename <- paste(tempfile(), ".mat", sep = "")
 res <- tryCatch({
-  writeMat(filename, x=1, matVersion="99")
-}, error = function(ex) ex)
+  writeMat(filename, x = 1, matVersion = "99")
+}, error = identity)
 print(res)
 unlink(filename)
 
@@ -278,8 +279,8 @@ message("writeMat() - Octave compatibility ...")
 
 value <- double(0L)
 filename <- file.path(tempdir(), "octave-bug42562-empty.mat")
-writeMat(filename, value=value, verbose=-120)
-data <- readMat(filename, verbose=-100)
+writeMat(filename, value = value, verbose = -120)
+data <- readMat(filename, verbose = -100)
 value2 <- data$value
 str(value2)
 stopifnot(length(value2) == length(value))
@@ -287,8 +288,8 @@ stopifnot(all(value2 == value))
 
 value <- 0
 filename <- file.path(tempdir(), "octave-bug42562-scalar.mat")
-writeMat(filename, value=value, verbose=-120)
-data <- readMat(filename, verbose=-100)
+writeMat(filename, value = value, verbose = -120)
+data <- readMat(filename, verbose = -100)
 value2 <- data$value
 str(value2)
 stopifnot(length(value2) == length(value))
@@ -296,8 +297,8 @@ stopifnot(all(value2 == value))
 
 value <- 1:5
 filename <- file.path(tempdir(), "octave-bug42562-vector.mat")
-writeMat(filename, value=value, verbose=-120)
-data <- readMat(filename, verbose=-100)
+writeMat(filename, value = value, verbose = -120)
+data <- readMat(filename, verbose = -100)
 value2 <- data$value
 str(value2)
 stopifnot(length(value2) == length(value))
